#! /usr/bin/python3
# text2me ——通过Twilio发消息给自己手机
# 用法：准备一个txt文件，按照以下格式布局：
# 账户SID
# AUTH认证标识
# 发送者手机号（必须加国家号）
# 接收者手机号（必须加国家号）
# import text2me;text2me.send('消息', '文件路径')

from twilio.rest import Client


def send(msg, config_file):
    with open(config_file) as f:
        account_sid, auth_token, from_phone, to_phone = f.readlines()
    Client(account_sid, auth_token).messages.create(body=msg, from_=from_phone, to=to_phone)



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="Text2Me",
    version="0.0.1",
    author="CHUA某人",
    author_email="chua-x@outlook.com",
    description="text2me ——通过Twilio发消息给自己手机",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/CHUA-X/Text2Me",
    packages=setuptools.find_packages(where='./src'),
    package_dir={"": "src"},
    keyword=['Python', 'python', 'Twilio'],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: Chinese (Simplified)",
        "Natural Language :: English",
        "Operating System :: Unix",
        "Operating System :: POSIX :: Linux",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ],
    python_requires='>=3.6',
)
